pub trait Selector<State> { type Output; // Required method fn select(&self, state: State) -> Option<Self::Output>; }
Selector defines what a task created by ReactiveTask will do.
ReactiveTask
The Option value in the output indicates that Future is still pending if Some, or that the task is ready if Some.